@@ -9,9 +9,9 @@ import mlib from 'ssb-msgs'
 import ssbref from 'ssb-ref'
 import threadlib from 'patchwork-threads'
 import ReactInfinite from 'react-infinite'
+import ComposerCard from './composer/card'
 import SimpleInfinite from './simple-infinite'
 import Summary from './msg-view/summary'
-import Tabs from './tabs'
 import { VerticalFilledContainer, verticalFilled } from './index'
 import { isaReplyTo } from '../lib/msg-relation'
 import app from '../lib/app'
@@ -38,8 +38,6 @@ export default class MsgList extends React.Component {
       selected: null,
       isLoading: false,
       isAtEnd: false,
-      searchQuery: false,
-      activeFilter: props.filters ? props.filters[0] : null,
       containerHeight: window.innerHeight
     }
     this.liveStream = null
@@ -83,6 +81,17 @@ export default class MsgList extends React.Component {
           app.ssb.private.publish(voteMsg, recps, done)
         }
       },
+      onIsread: (e) => {
+        // try to find the message
+        for (var i=0; i < this.state.msgs.length; i++) {
+          let msg = this.state.msgs[i]
+          if (msg.key === e.key) {
+            msg.hasUnread = !e.value
+            this.setState({ msgs: this.state.msgs })
+            return
+          }
+        }
+      },
       onFlag: (msg, reason) => {
         if (!reason)
           throw new Error('reason is required')
@@ -106,11 +115,6 @@ export default class MsgList extends React.Component {
           let recps = mlib.links(msg.value.content.recps).map(l => l.link)
           app.ssb.private.publish(voteMsg, recps, done)
         }
-      },
-      onSelectFilter: (filter) => {
-        if (this.state.isLoading)
-          return
-        this.setState({ activeFilter: filter }, () => this.reload())
       }
     }
   }
@@ -118,21 +122,24 @@ export default class MsgList extends React.Component {
   componentDidMount() {
     // load first messages
     var start = Date.now()
-    this.loadMore({ amt: DEFAULT_BATCH_LOAD_AMT }, () => console.log(Date.now() - start))
+    this.loadMore({ amt: this.props.DEFAULT_BATCH_LOAD_AMT }, () => console.log(Date.now() - start))
 
     // setup autoresizing
     this.calcContainerHeight()
     this.resizeListener = this.calcContainerHeight.bind(this)
     window.addEventListener('resize', this.resizeListener)
 
+    // listen to isread changes
+    app.on('update:isread', this.handlers.onIsread)
+
     // setup livestream
     if (this.props.live)
       this.setupLivestream()
   }
   componentWillUnmount() {
-    // stop autoresizing
+    // stop listeners
     window.removeEventListener('resize', this.resizeListener)
-    // abort livestream
+    app.removeListener('update:isread', this.handlers.onIsread)
     if (this.liveStream)
       this.liveStream(true, ()=>{})
   }
@@ -189,8 +196,7 @@ export default class MsgList extends React.Component {
       pull.asyncMap((msg, cb) => threadlib.decryptThread(app.ssb, msg, cb)), // decrypt the message
       (this.props.filter) ? pull.filter(this.props.filter) : undefined, // run the fixed filter
       pull.asyncMap(this.processMsg.bind(this)), // fetch the thread
-      (this.state.activeFilter) ? pull.filter(this.state.activeFilter.fn) : undefined, // run the user-selected filter
-      (this.state.searchQuery) ? pull.filter(this.searchQueryFilter.bind(this)) : undefined,
+      (this.props.searchRegex) ? pull.filter(this.searchQueryFilter.bind(this)) : undefined,
       pull.drain(msg => {
 
         if (this.props.queueNewMsgs) {
@@ -232,29 +238,6 @@ export default class MsgList extends React.Component {
     this.loadMore({ amt })
   }
 
-  onSearchKeyDown(e) {
-    if (e.keyCode == 13) { // on enter
-      var query = e.target.value
-      if (query && query.trim()) {
-        if (ssbref.isLink(query)) {
-          // a link, lookup
-          if (ssbref.isFeedId(query)) {
-            app.history.pushState(null, '/profile/'+encodeURIComponent(query))
-          } else if (ssbref.isMsgId(query)) {
-            app.history.pushState(null, '/msg/'+encodeURIComponent(query))
-          } else if (ssbref.isBlobId(query)) {
-            app.history.pushState(null, '/webview/'+encodeURIComponent(query))            
-          }
-        } else {
-          // text query
-          query = new RegExp(query, 'i')
-        }
-      } else
-        query = false
-      this.reload({ searchQuery: query })
-    }
-  }
-
   processMsg(msg, cb) {
     // fetch thread data if not already present (using `related` as an indicator of that)
     if (this.props.threads && !('related' in msg)) {
@@ -265,7 +248,7 @@ export default class MsgList extends React.Component {
 
   searchQueryFilter(thread) {
     // iterate the thread and its posts, looking for matches
-    let query = this.state.searchQuery
+    const regex = this.props.searchRegex
     if (checkMatch(thread))
       return true
     // if (!thread.related)
@@ -277,10 +260,9 @@ export default class MsgList extends React.Component {
     return false
 
     function checkMatch (msg) {
-      if (msg.value.content.type !== 'post' || (msg !== thread && !isaReplyTo(msg, thread)))
+      if (msg.value.content.type !== 'post')
         return false
-      // console.log('check match', query.test(''+msg.value.content.text), msg.value.content.text)
-      return query.test(''+msg.value.content.text)
+      return regex.test(''+msg.value.content.text)
     }
   }
 
@@ -301,9 +283,8 @@ export default class MsgList extends React.Component {
       pull.asyncMap((msg, cb) => threadlib.decryptThread(app.ssb, msg, cb)), // decrypt the message
       (this.props.filter) ? pull.filter(this.props.filter) : undefined, // run the fixed filter
       pull.asyncMap(this.processMsg.bind(this)), // fetch the thread
-      (this.state.activeFilter) ? pull.filter(this.state.activeFilter.fn) : undefined, // run the user-selected filter
+      (this.props.searchRegex) ? pull.filter(this.searchQueryFilter.bind(this)) : undefined,
       pull.take(amt), // apply limit
-      (this.state.searchQuery) ? pull.filter(this.searchQueryFilter.bind(this)) : undefined,
       pull.collect((err, msgs) => {
         if (err)
           console.warn('Error while fetching messages', err)
@@ -352,6 +333,8 @@ export default class MsgList extends React.Component {
   }
 
   render() {
+    const Hero = this.props.Hero
+    const Toolbar = this.props.Toolbar
     const Infinite = this.props.listItemHeight ? ReactInfinite : SimpleInfinite // use SimpleInfinite if we dont know the height of each elem
     const ListItem = this.props.ListItem || Summary
     const selectedKey = this.state.selected && this.state.selected.key
@@ -359,14 +342,10 @@ export default class MsgList extends React.Component {
     const append = (this.state.isAtEnd && this.props.append) ? this.props.append() : ''
     const nQueued = this.state.newMsgQueue.length
     const endOfToday = moment().endOf('day')
-    var lastDate = moment().startOf('day')
+    var lastDate = moment().startOf('day').add(1, 'day')
     return <div className={'msg-list'+(this.state.selected?' msg-is-selected':'')}>
       <div className="msg-list-items">
-        <div className="msg-list-ctrls toolbar">
-          { this.props.toolbar ? this.props.toolbar() : '' }
-          { this.props.search  ? <div className="search"><i className="fa fa-search" /><input onKeyDown={this.onSearchKeyDown.bind(this)} /></div> : '' }
-          { this.props.filters ? <Tabs options={this.props.filters} selected={this.state.activeFilter} onSelect={this.handlers.onSelectFilter} /> : '' }
-        </div>
+        { Toolbar ? <Toolbar/> : '' }
         <Infinite
           id="msg-list-infinite"
           ref="container"
@@ -376,15 +355,15 @@ export default class MsgList extends React.Component {
           onInfiniteLoad={this.onInfiniteLoad.bind(this)}
           loadingSpinnerDelegate={this.loadingElement()}
           isInfiniteLoading={this.state.isLoading} >
-          { this.props.hero ? this.props.hero() : '' }
+          { Hero ? <Hero/> : '' }
           { nQueued ?
             <a className="new-msg-queue" onClick={this.reload.bind(this)}>{nQueued} new update{u.plural(nQueued)}</a>
             : '' }
+          { this.props.composer ? <ComposerCard {...this.props.composerProps} /> : '' }
+          { this.state.isLoading ? <div style={{fontWeight: 300, textAlign: 'center'}}>Loading...</div> : '' }
           { isEmpty ?
             <div className="empty-msg">
-              { this.state.searchQuery ?
-                'No results found.' :
-                (this.props.emptyMsg || 'No new messages.') }
+              { (this.props.emptyMsg || 'No messages.') }
             </div>
             :
             <ReactCSSTransitionGroup component="div" transitionName="fade" transitionAppear={true} transitionAppearTimeout={500} transitionEnterTimeout={500} transitionLeaveTimeout={1}>
@@ -394,14 +373,18 @@ export default class MsgList extends React.Component {
                   key={m.key}
                   msg={m}
                   {...this.handlers}
+                  {...this.props.listItemProps}
                   selected={selectedKey === m.key}
                   forceRaw={this.props.forceRaw} />
 
+                // render a date divider if this post is from a different day than the last
                 const oldLastDate = lastDate
                 const lastPost = threadlib.getLastThreadPost(m)
                 lastDate = moment(lastPost.value.timestamp)
-                if (this.props.dateDividers && !lastDate.isSame(oldLastDate, 'day'))
-                  return <div key={m.key}><hr className="msgs-divider" data-label={lastDate.endOf('day').from(endOfToday)} />{item}</div>
+                if (this.props.dateDividers && !lastDate.isSame(oldLastDate, 'day')) {
+                  let label = (lastDate.isSame(endOfToday, 'day')) ? 'today' : lastDate.endOf('day').from(endOfToday)
+                  return <div key={m.key}><hr className="msgs-divider" data-label={label} />{item}</div>
+                }
                 return item
               }) }
             </ReactCSSTransitionGroup>
